<template>
  <!-- 案件审核 -->
  <div>
    <el-dialog
      :before-close="handleClose"
      :close-on-click-modal="false"
      :visible.sync="showFormDia"
      title="服务明星详情"
      top="8vh"
      width="60%"
    >
      <div>
        <el-descriptions :column="3" :size="size" border class="margin-top">
          <el-descriptions-item :span="3" label="姓名"
          >{{ params.name }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="性别"
          >{{ params.sex }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="部门"
          >{{ params.orgName }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="服务箴言"
          >{{ params.motto }}
          </el-descriptions-item>
          <el-descriptions-item :span="2" label="考评周期类型">
            <el-tag
              :type=" params.cycle === 1 ? '' : params.cycle === 2 ? '' : params.cycle === 3 ? '' : '' ">
              {{
                params.cycle === 1 ? '年' :
                  params.cycle === 2 ? '季' :
                    params.cycle === 3 ? '月' :
                      params.cycle || '-'
              }}
            </el-tag>
          </el-descriptions-item>

          <el-descriptions-item :span="3" label="考评期(年份)"
          >{{ params.year }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="考评期(季度)"
          >{{ params.quarter || '-' }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="考评期(月份)"
          >{{ params.month || '-' }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="说明"
          >{{ params.remark }}
          </el-descriptions-item>
          <el-descriptions-item :span="3" label="照片">
            <!--            {{ params.fileList }}-->
            <div v-if="params.fileList && params.fileList.length > 0">
              <el-image
                :preview-src-list="[params.fileList[0].url]"
                :src="params.fileList[0].url"
                fit="cover"
                style="width: 100px; height: 100px;"
              ></el-image>
            </div>
            <span v-else>-</span>
          </el-descriptions-item>
          <!--          <el-descriptions-item :span="4" label="巡逻附件图片">-->
          <!--            <el-image-->
          <!--              v-for="(item, index) in imgList"-->
          <!--              :key="index"-->
          <!--              :preview-src-list="srcList"-->
          <!--              :src="previewUrl + item"-->
          <!--              alt=""-->
          <!--              style="width: 6rem;height: 6rem;"-->
          <!--              @click="handlePictureCardPreview(item, index)"-->
          <!--            />-->
          <!--          </el-descriptions-item>-->

        </el-descriptions>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import {dictionaryEscape} from '@/utils/dictionary'
import ServiceStar from '@/views/Manage/duty/api/ServiceStar'
import {mapState} from 'vuex'
import dictUtils from '@/components/dict/DictSelectUtils.js'

export default {
  name: 'CmgtSaftyPlanFormDialog',
  components: {},
  props: {},
  data() {
    return {
      srcList: [],
      imgList: [],
      imgListCheck: [],
      previewUrl:
        window.context.portal +
        '/file/onlinePreviewController/v1/getFileById_',
      size: '',
      showFormDia: false,
      newParams: {
        pageBean: {
          pageSize: -1,
          page: 1
        },
        querys: [
          {
            group: 'main',
            operation: 'LIKE',
            parentGroup: '',
            property: 'target_is_check_',
            relation: 'AND',
            value: '是'
          }
        ]
      },
      aqywlbList: [],
      params: {
        caseFile: []
      }
    }
  },
  computed: mapState({
    header: state => {
      return {
        Authorization: `Bearer ${state.login.currentUser.token}`
      }
    }
  }),
  created() {
    this.aqywlbList = dictUtils.getDictItemsFromCache('aqywlb')
  },
  methods: {
    dictionaryEscape,
    handlePictureCardPreview(file, index) {
      let images = []
      let startPosition = 0

      this.imgList.map((e, ix) => {
        if (e === file.id) {
          startPosition = ix
        }
        images.push(this.previewUrl + e)
      })
      this.imgListCheck.map((e, ix) => {
        if (e === file.id) {
          startPosition = ix
        }
        images.push(this.previewUrl + e)
      })
      this.srcList = images
    },
    handleClose() {
      this.params = {}
      this.imgList = []
      this.imgListCheck = []
      this.showFormDia = false
    },
    Update(row) {
      this.showFormDia = true
      ServiceStar.getCmgtDutyJobByID(row.id, res => {
        this.params = res
        if (this.params.filePath) {
          this.params.fileList = [{
            id: this.params.filePath,
            name: res.fileName || '未命名文件',
            url: this.previewUrl + this.params.filePath
          }]
        } else {
          this.params.fileList = []
        }
      })
    }
  }
}
</script>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}

::v-deep .el-descriptions-item__label {

}

::v-deep .el-descriptions-item__content {
  max-width: 295px; // 给内容增加最大宽度
  word-break: break-all; // 让内容超出列宽时自动换行显示
  word-wrap: break-word;
}
</style>
